PointAnimationSequence class

PointAnimationSequence类会根据给定的Point对象和needHighLight变量,生成一个动画序列,其中包含了一系列逐渐变化字号大小的段落对象

Constructors

PointAnimationSequence(BallPoint point, bool needHighLight)

Properties

hashCode → int
The hash code for this object.
no setterinherited
needHighLight ↔ bool
getter/setter pair
paragraphs ↔ Queue<Paragraph>
getter/setter pair
point ↔ BallPoint
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited