RBallView class

Inheritance

Constructors

RBallView({Key? key, required MediaQueryData mediaQueryData, required List<RBallTagData> keywords, required List<RBallTagData> highlight, int maxChar = 8, dynamic onTapRBallTagCallback(RBallTagData)?, bool isAnimate = true, bool isAllowScale = true, required bool isAllowNext, bool isShowLine = false, Decoration? decoration, bool isShowDecoration = false, List<double>? centers, int? radius, Color? textColor, Color? highLightTextColor, RBallController? controller})
const

Properties

centers → List<double>?
仰角基准值 均匀分布仰角
final
controller → RBallController?
final
decoration → Decoration?
球体容器装饰
final
hashCode → int
The hash code for this object.
no setterinherited
highlight → List<RBallTagData>
需要高亮的关键词
final
highLightTextColor → Color?
文字高亮颜色
final
isAllowNext → bool
是否允许点击到下一级数据
final
isAllowScale → bool
是否允许双指缩放
final
isAnimate → bool
是否运行动画
final
isShowDecoration → bool
是否展示球体容器装饰
final
isShowLine → bool
是否显示球心连线
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keywords → List<RBallTagData>
需要展示的关键词
final
maxChar → int
最多显示多个字符
final
mediaQueryData → MediaQueryData
final
onTapRBallTagCallback → dynamic Function(RBallTagData)?
点击回调
final
radius → int?
球体半径
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textColor → Color?
文字颜色
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited